# Experimental iPodder reskin.py

import os
import os.path
import logging
import urllib2
import urlparse
import wx
import sys
from xml.dom.minidom import parse

log = logging.getLogger('iPodder')

# Overrides for values in skin.py

PRODUCT_NAME = 'WNCW Pubcatcher'
PRODUCT_NAME_SHORT = 'Pubcatcher'
CURRENT_VERSION_URL = "http://www.pubcatcher.org/wncw/current_version.xml"
WEBSITE_URL = "http://wncw.org/"
HELP_URL = "http://www.pubcatcher.org/help/"

SPLASH_LIFETIME = 30000000

DEFAULT_SUBS = [
    ('Welcome to Pubcatcher',
             'http://pubcatcher.org/wncw/welcome.xml'),
    ]
PODCAST_DIRECTORY_ROOTS = [
    ('http://pubcatcher.org/wncw/podcasts.opml', 'WNCW Podcasts'),
    ('http://pubcatcher.org/wncw/picks.opml', 'WNCW Picks'),
    ('http://pubcatcher.org/pubradio.opml', 'Public Radio Podcasts'),
    ]

# New values (must be specified in ATTS to be loaded).
BANNER_DATA_URL = 'http://www.pubcatcher.org/wncw/banner.xml'
BANNER_IMAGE = 'images/banner.png'
BANNER_CLICK_URL = 'http://www.wncw.org/'

banner = None

def GetBannerImage(ipodder):
    try:
        global banner
        if not banner:
            banner = Banner(ipodder)
        return banner.image
    except:
        log.exception("Couldn't GetBannerImage:")
        return wx.Image(BANNER_IMAGE)
    
def ReloadBanner(ipodder):
    try:
        global banner
        if not banner:
            banner = Banner(ipodder)
        banner.refresh()
        return 1
    except:
        log.exception("Couldn't ReloadBanner:")
        return 0
    
def GetBannerUrl(ipodder):
    try:
        global banner
        if not banner:
            banner = Banner(ipodder)
        return banner.clickurl
    except:
        log.exception("Couldn't GetbannerUrl:")
        return BANNER_CLICK_URL

ATTS = [
    'GetBannerImage',
    'ReloadBanner',
    'GetBannerUrl',
    ]


def getElementText(doc, tag):
    text = ""
    for node in doc.getElementsByTagName(tag)[0].childNodes:
        if node.nodeType == node.TEXT_NODE:
            text += node.data
    return text

class Banner:
    def __init__(self, ipodder):
        self.ipodder = ipodder

        self.basepath = os.path.abspath(os.path.split(sys.argv[0])[0]) # UGH!

        # Set these first, so they'll be the default if anything goes wrong.
        self.image = wx.Image(os.path.join(self.basepath,BANNER_IMAGE))
        self.clickurl = BANNER_CLICK_URL

        self.banner_dir = os.path.join(self.ipodder.config.appdata_dir, 'banner')
        if not os.path.exists(self.banner_dir):
            os.makedirs(self.banner_dir)
        self.banner_xml_filename = os.path.join(self.banner_dir, "banner.xml")
        if os.path.exists(self.banner_xml_filename):
            self.load()
            
    def parse(self):
        bannerdom = parse(open(self.banner_xml_filename))
        self.clickurl = getElementText(bannerdom, "clickurl")
        self.imageurl = getElementText(bannerdom, "imageurl")
        self.imagename = os.path.split(urlparse.urlparse(self.imageurl)[2])[1]
        
    def load(self):
        self.parse()
        self.image = wx.Image(os.path.join(self.banner_dir, self.imagename))
    
    def pull(self):
        # Pull the Banner xml.
        bannerxml = urllib2.urlopen(BANNER_DATA_URL)
        fbannerxml = open(os.path.join(self.banner_dir, "banner.xml"), "w")
        fbannerxml.write(bannerxml.read())
        fbannerxml.close()
        
        # Parse the XML to pull the image.
        self.parse()
        imgdata = urllib2.urlopen(self.imageurl).read()
        open(os.path.join(self.banner_dir, self.imagename), "wb").write(imgdata)

    def refresh(self):
        self.pull()
        self.load()
        
def Test():
    logging.basicConfig
    class any: pass
    ipodder = any()
    ipodder.config = any()
    ipodder.config.appdata_dir = 'c:\\foo'
    return GetBannerImage(ipodder)
